@@ -1,6 +1,6 @@
 
 
-"""Jaime Sendra Berenguer-2018-2022.
+"""Jaime Sendra Berenguer-2020.
 MLearner Machine Learning Library Extensions
 Author:Jaime Sendra Berenguer<www.linkedin.com/in/jaisenbe>
 License: MIT
