@@ -1,12 +1,12 @@
 
-"""Jaime Sendra Berenguer-2018-2022.
+"""Jaime Sendra Berenguer-2020.
 MLearner Machine Learning Library Extensions
 Author:Jaime Sendra Berenguer <www.linkedin.com/in/jaisenbe>
 License: MIT
 """
 
 
-from .voting import MajorityVoteClassifier
+# from .voting import MajorityVoteClassifier
 
 
-__all__ = ["MajorityVoteClassifier"]
+# __all__ = ["MajorityVoteClassifier"]
